@@ -44,12 +44,12 @@ static struct option axel_options[] =
 	/* name			has_arg	flag	val */
 	{ "max-speed",		1,	NULL,	's' },
 	{ "num-connections",	1,	NULL,	'n' },
-	{ "output",		1,	NULL,	'o' },
+	{ "output",			1,	NULL,	'o' },
 	{ "search",		2,	NULL,	'S' },
 	{ "no-proxy",		0,	NULL,	'N' },
-	{ "quiet",		0,	NULL,	'q' },
+	{ "quiet",			0,	NULL,	'q' },
 	{ "verbose",		0,	NULL,	'v' },
-	{ "help",		0,	NULL,	'h' },
+	{ "help",			0,	NULL,	'h' },
 	{ "version",		0,	NULL,	'V' },
 	{ "alternate",		0,	NULL,	'a' },
 	{ "header",		1,	NULL,	'H' },
@@ -343,33 +343,39 @@ int main( int argc, char *argv[] )
 	
 	while( !axel->ready && run )
 	{
+
 		long long int prev, done;
 		
 		prev = axel->bytes_done;
 		axel_do( axel );
 		
 		if( conf->alternate_output )
-		{			
-			if( !axel->message && prev != axel->bytes_done )
+		{		
+				if( !axel->message && prev != axel->bytes_done )
 				print_alternate_output( axel );
 		}
 		else
 		{
-			/* The infamous wget-like 'interface'.. ;)		*/
+			
+			/* The infamous wget-like 'interface'.. ;)	DOTS	*/
 			done = ( axel->bytes_done / 1024 ) - ( prev / 1024 );
 			if( done && conf->verbose > -1 )
 			{
 				for( i = 0; i < done; i ++ )
 				{
 					i += ( prev / 1024 );
-					if( ( i % 50 ) == 0 )
+					if( ( i % 30 ) == 0 )
 					{
 						if( prev >= 1024 )
 							printf( "  [%6.1fKB/s]", (double) axel->bytes_per_second / 1024 );
+						
+						/*CHANGED*/
 						if( axel->size < 10240000 )
-							printf( "\n[%3lld%%]  ", min( 100, 102400 * i / axel->size ) );
+							printf( "\r[%3lld%%]  ", min( 100, 102400 * i / axel->size ) );
 						else
-							printf( "\n[%3lld%%]  ", min( 100, i / ( axel->size / 102400 ) ) );
+							printf( "\r[%3lld%%]  ", min( 100, i / ( axel->size / 102400 ) ) );
+						/*CHANGED*/
+
 					}
 					else if( ( i % 10 ) == 0 )
 					{
@@ -468,14 +474,18 @@ void print_commas( long long int bytes_done )
 {
 	int i, j;
 	
-	printf( "       " );
+	printf( " " );
 	j = ( bytes_done / 1024 ) % 50;
 	if( j == 0 ) j = 50;
 	for( i = 0; i < j; i ++ )
 	{
 		if( ( i % 10 ) == 0 )
 			putchar( ' ' );
-		putchar( ',' );
+		
+		/*CHANGED*/
+		/*putchar( ',' );*/
+		/*CHANGED*/
+
 	}
 	fflush( stdout );
 }
@@ -491,7 +501,7 @@ static void print_alternate_output(axel_t *axel)
 		
 	for(i=0;i<axel->conf->num_connections;i++)
 	{
-		for(;j<((double)axel->conn[i].currentbyte/(total+1)*50)-1;j++)
+		for(;j<((double)axel->conn[i].currentbyte/(total+1)*30)-1;j++)
 			putchar('.');
 
 		if(axel->conn[i].currentbyte<axel->conn[i].lastbyte)
@@ -505,7 +515,7 @@ static void print_alternate_output(axel_t *axel)
 
 		j++;
 		
-		for(;j<((double)axel->conn[i].lastbyte/(total+1)*50);j++)
+		for(;j<((double)axel->conn[i].lastbyte/(total+1)*30);j++)
 			putchar(' ');
 	}
 	
